@@ -40,7 +40,7 @@ type Machine struct {
 	Config     *MachineConfig        `json:"config,omitempty"`
 	Events     []*MachineEvent       `json:"events,omitempty"`
 	Checks     []*MachineCheckStatus `json:"checks,omitempty"`
-	LeaseNonce string
+	LeaseNonce string                `json:"nonce,omitempty"`
 }
 
 func (m *Machine) FullImageRef() string {
@@ -461,6 +461,8 @@ type MachineConfig struct {
 	// the standby machine will be started.
 	Standbys []string `json:"standbys,omitempty"`
 
+	StopConfig *StopConfig `json:"stop_config,omitempty"`
+
 	// Deprecated: use Guest instead
 	VMSize string `json:"size,omitempty"`
 	// Deprecated: use Service.Autostart instead
@@ -504,6 +506,11 @@ type DNSConfig struct {
 	SkipRegistration bool `json:"skip_registration,omitempty"`
 }
 
+type StopConfig struct {
+	Timeout *Duration `json:"timeout,omitempty"`
+	Signal  *string   `json:"signal,omitempty"`
+}
+
 type MachineLease struct {
 	Status  string            `json:"status,omitempty"`
 	Data    *MachineLeaseData `json:"data,omitempty"`
@@ -531,6 +538,7 @@ type LaunchMachineInput struct {
 	Region     string         `json:"region,omitempty"`
 	Config     *MachineConfig `json:"config,omitempty"`
 	SkipLaunch bool           `json:"skip_launch,omitempty"`
+	LeaseTTL   int            `json:"lease_ttl,omitempty"`
 	// Client side only
 	SkipHealthChecks bool
 }
